# Because it was too easy to just make this a pdf. 
Below is a simple package which has methods for displaying details about my experience, skills, hobbies, current projects, some inspirational quotes, and resume. 

## Install
```
pip install kennypavan
```

## Usage
```python
from KennyPavan import KennyPavan

#treating myself as an object
kp = KennyPavan()

#about me
kp.about()

#skillset
kp.skills()

#experience
kp.experience()

#education
kp.education()

#show any publications
kp.publications()

```

<br />

## Displaying all
```python
from KennyPavan import KennyPavan
kp = KennyPavan()
kp.displayAll()
```

<br />
<br />

<font size="18px">🤷</font><br />
<i>There's also a few properties</i>
